@@ -6,6 +6,7 @@
 #include <QThread>
 #include <QSemaphore>
 #include <stdio.h>
+#include "ImageItem.h"
 #ifdef Q_WS_MAEMO_5
 #include <FCam/N900.h>
 #define deviceN900 true
@@ -18,6 +19,8 @@
 #include <QString>
 #include <QSettings>
 #include "feedback.h"
+#include "pasyncfilewriter.h"
+#include "paccelerometer.h"
 
 class OverlayWidget;
 
@@ -27,7 +30,7 @@ class CameraThread : public QThread {
 public:
     CameraParameters* parameters;
     feedBack feedback;
-    FCam::AsyncFileWriter writer;
+    pAsyncFileWriter* writer;
     CameraThread(OverlayWidget *o, QObject *parent = NULL) : QThread(parent) {
         overlay = o;
         keepGoing = true;
@@ -35,12 +38,18 @@ public:
         active = true;
         cameralock = new QSemaphore(1);
         parameters = new CameraParameters;
+        writer = new pAsyncFileWriter;
+        takeSnapshot = false;
+        accelerometer = new pAccelerometer();
     }
 
 
 public slots:
     void stop() {
         keepGoing = false;
+        active = false;
+        writer->finish();
+        qDebug()<<"stop" << keepGoing;
     }
 
     void pause() {
@@ -80,6 +89,7 @@ signals:
     void gainChanged(int);
     void pictureSaved(QString);
     void lensCoverClosed();
+    void newImage(ImageItem *);
 
 protected:
     void run();
@@ -89,8 +99,10 @@ private:
     bool active;
     bool focus;
     bool takeSnapshot;
+    pAccelerometer *accelerometer;
     OverlayWidget *overlay;
     QSemaphore *cameralock;
+    enum {SHARPEST = 215};
 };
 
 #endif
